@@ -19,7 +19,7 @@ use Version::Compare;
 use Path::Class;
 use ExtUtils::Installed;
 
-our $VERSION = '0.064';
+our $VERSION = '0.065';
 
 =head1 NAME
 
@@ -274,12 +274,24 @@ sub clean_everything {
 	# Remove any qw(xxxxx xxxxx) or qw[xxx xxxxx]
 	# '\(' are for real 'qw()' parenthesis not for grouping
 	# Also removes empty qw()
-	$module =~ s{
+
+        # With spaces and parenthesis e.g. qw( foo bar )
+        $module =~ s{
 			\s qw
 			\(
 			(\s*[A-Za-z]+(\s*[A-Za-z]*))*\s*
 			\)
 		}{}xi;
+
+        # Without spaces, with  parenthesis e.g. qw(foo bar) and optionnal [method_names
+        $module =~ s{
+			\s qw
+			\(
+			([A-Za-z]+(_[A-Za-z]+)*(\s*[A-Za-z]*))*
+			\)
+		}{}xi;
+
+        # With square brackets e.g. qw[foo bar] and optionnal [method_names]
 	$module =~ s{
 			\s qw
 			\[
@@ -287,7 +299,7 @@ sub clean_everything {
 			\]
 		}
 		    {}xi; # Empty subtitution
-
+        # With spaces and parenthesis e.g. qw/ foo bar /
 	$module =~ s{
 			\s qw
 			\/
@@ -641,6 +653,15 @@ things, even if Ack do the stuff proudly this way.
 Thanks to cpantesters.org community reports, things should go better and
 better.
 
+=head2 Fun : some are able to do it using a one-liner
+
+Command Line Magic (@climagic) tweeted 4:17 PM on lun., nov. 25, 2013
+
+    # Not perfect, but gives you a start on the Perl modules in use.
+    grep -rh ^use --include="*.pl" --include="*.pm" . | sort | uniq -c
+
+See original Tweet https://twitter.com/climagic/status/404992356513902592
+
 =cut
 
 =head1 BUGS
